@@ -224,6 +224,21 @@ function makeSignature(params) {
 	return signature;
 }
 
+
+/** Build output for displaying method parameters.  Just return JSON, this is not visible in the web page. */
+function makeMethodSignature(params) {
+    let json = JSON.stringify(params);
+
+    json = json.replaceAll("\"", "&quot;")
+    json = json.replaceAll("<", "&lt;")
+    json = json.replaceAll(">", "&gt;")
+    json = json.replaceAll("'", "&#39;")
+    json = json.replaceAll("&", "&amp;")
+
+    return json;
+}
+
+
 /** Find symbol {@link ...} strings in text and turn into html links */
 function resolveLinks(str, from) {
 	str = str.replace(/\{@link ([^} ]+) ?\}/gi,
