@@ -107,7 +107,8 @@ JXG.extend(
             c3d[2] /= le;
             c3d[3] /= le;
 
-            this.zIndex = Mat.matVecMult(this.view.matrix3DRotShift, c3d)[3];
+            // this.zIndex = Mat.matVecMult(this.view.matrix3DRotShift, c3d)[3];
+            this.zIndex = Mat.innerProduct(this.view.matrix3DRotShift[3], c3d);
 
             return this;
         }
