@@ -66,10 +66,10 @@ JXG.Point = function (board, coordinates, attributes) {
     this.element = this.board.select(attributes.anchor);
     this.coordsConstructor(coordinates);
 
-    this.elType = "point";
+    this.elType = 'point';
 
     /* Register point at board. */
-    this.id = this.board.setId(this, "P");
+    this.id = this.board.setId(this, 'P');
     this.board.renderer.drawPoint(this);
     this.board.finalizeAdding(this);
 
@@ -81,7 +81,7 @@ JXG.Point = function (board, coordinates, attributes) {
  * Inherits here from {@link JXG.GeometryElement}.
  */
 JXG.Point.prototype = new GeometryElement();
-Type.copyPrototypeMethods(JXG.Point, CoordsElement, "coordsConstructor");
+Type.copyPrototypeMethods(JXG.Point, CoordsElement, 'coordsConstructor');
 
 JXG.extend(
     JXG.Point.prototype,
@@ -108,7 +108,7 @@ JXG.extend(
                 prec = this.board.options.precision.hasPoint;
             }
             r = parseFloat(this.evalVisProp('size'));
-            if (unit === "user") {
+            if (unit === 'user') {
                 r *= Math.sqrt(Math.abs(this.board.unitX * this.board.unitY));
             }
 
@@ -155,7 +155,7 @@ JXG.extend(
             this.transformations[0].update();
             if (this === this.baseElement) {
                 // Case of bindTo
-                c = this.transformations[0].apply(this, "self");
+                c = this.transformations[0].apply(this, 'self');
             } else {
                 c = this.transformations[0].apply(this.baseElement);
             }
@@ -173,7 +173,7 @@ JXG.extend(
          * @private
          */
         updateRenderer: function () {
-            this.updateRendererGeneric("updatePoint");
+            this.updateRendererGeneric('updatePoint');
             return this;
         },
 
@@ -196,10 +196,7 @@ JXG.extend(
 
             func = Geometry.intersectionFunction(
                 this.board,
-                el1,
-                el2,
-                i,
-                j,
+                el1, el2, i, j,
                 this.visProp.alwaysintersect
             );
             this.addConstraint([func]);
@@ -218,7 +215,7 @@ JXG.extend(
             }
 
             this.type = Const.OBJECT_TYPE_INTERSECTION;
-            this.elType = "intersection";
+            this.elType = 'intersection';
             this.parents = [el1.id, el2.id, i, j];
 
             this.generatePolynomial = function () {
@@ -493,7 +490,7 @@ JXG.extend(
 JXG.createPoint = function (board, parents, attributes) {
     var el, attr;
 
-    attr = Type.copyAttributes(attributes, board.options, "point");
+    attr = Type.copyAttributes(attributes, board.options, 'point');
     el = CoordsElement.create(JXG.Point, board, parents, attr);
     if (!el) {
         throw new Error(
@@ -566,7 +563,7 @@ JXG.createPoint = function (board, parents, attributes) {
 JXG.createGlider = function (board, parents, attributes) {
     var el,
         coords,
-        attr = Type.copyAttributes(attributes, board.options, "glider");
+        attr = Type.copyAttributes(attributes, board.options, 'glider');
 
     if (parents.length === 1) {
         coords = [0, 0];
@@ -621,7 +618,7 @@ JXG.createGlider = function (board, parents, attributes) {
 JXG.createIntersectionPoint = function (board, parents, attributes) {
     var el, el1, el2, func,
         i, j,
-        attr = Type.copyAttributes(attributes, board.options, "intersection");
+        attr = Type.copyAttributes(attributes, board.options, 'intersection');
 
     // make sure we definitely have the indices
     parents.push(0, 0);
@@ -652,7 +649,7 @@ JXG.createIntersectionPoint = function (board, parents, attributes) {
     }
 
     el.type = Const.OBJECT_TYPE_INTERSECTION;
-    el.elType = "intersection";
+    el.elType = 'intersection';
     el.setParents([el1.id, el2.id]);
 
     /**
@@ -684,7 +681,7 @@ JXG.createIntersectionPoint = function (board, parents, attributes) {
 };
 
 /**
- * @class Given a set of intersection points, this is another ("other") intersection point,
+ * @class Given a set of intersection points, this is another ('other') intersection point,
  * @pseudo
  * @description If two elements of type curve, circle or line intersect in more than one point, with this element it is possible
  * to construct the "other" intersection. This is a an intersection which is different from a supplied point or different from any
@@ -840,7 +837,7 @@ JXG.createOtherIntersectionPoint = function (board, parents, attributes) {
     el.addConstraint([func]);
 
     el.type = Const.OBJECT_TYPE_INTERSECTION;
-    el.elType = "otherintersection";
+    el.elType = 'otherintersection';
     el.setParents([el1.id, el2.id]);
     el.addParents(others);
 
@@ -996,7 +993,7 @@ JXG.createPolePoint = function (board, parents, attributes) {
         attributes
     );
 
-    el.elType = "polepoint";
+    el.elType = 'polepoint';
     el.setParents([el1.id, el2.id]);
 
     el1.addChild(el);
