@@ -122,14 +122,14 @@ JXG.Turtle = function (board, parents, attributes) {
 
     this.turtleIsHidden = false;
     this.board = board;
-    this.visProp.curveType = "plot";
+    this.visProp.curveType = 'plot';
 
     // Save visProp in this._attributes.
     // this._attributes is overwritten by setPenSize, setPenColor...
     // Setting the color or size affects the turtle from the time of
     // calling the method,
     // whereas Turtle.setAttribute affects all turtle curves.
-    this._attributes = Type.copyAttributes(this.visProp, board.options, "turtle");
+    this._attributes = Type.copyAttributes(this.visProp, board.options, 'turtle');
     delete this._attributes.id;
 
     x = 0;
@@ -418,14 +418,16 @@ JXG.extend(
          * @returns {JXG.Turtle} pointer to the turtle object
          */
         clearScreen: function () {
-            var i,
-                el,
-                len = this.objects.length;
-
-            for (i = 0; i < len; i++) {
-                el = this.objects[i];
-                this.board.removeObject(el);
-            }
+            // var i,
+            //     el,
+            //     len = this.objects.length;
+            // for (i = len - 1; i >= 0; i--) {
+            //     el = this.objects[i];
+            //     this.board.removeObject(el);
+            // }
+            // It is much faster to remove the whole array of pathes.
+            this.board.removeObject(this.objects);
+            this.objects = [];
 
             this.init(0, 0, 90);
             return this;
@@ -841,7 +843,7 @@ JXG.extend(
                 return this.pos[0];
             }
 
-            return this.evalAt(t, "X");
+            return this.evalAt(t, 'X');
         },
 
         /**
@@ -854,7 +856,7 @@ JXG.extend(
             if (!Type.exists(t)) {
                 return this.pos[1];
             }
-            return this.evalAt(t, "Y");
+            return this.evalAt(t, 'Y');
         },
 
         /**
@@ -934,7 +936,7 @@ JXG.createTurtle = function (board, parents, attributes) {
     var attr;
     parents = parents || [];
 
-    attr = Type.copyAttributes(attributes, board.options, "turtle");
+    attr = Type.copyAttributes(attributes, board.options, 'turtle');
     return new JXG.Turtle(board, parents, attr);
 };
 
