@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2024
+    Copyright 2008-2025
         Matthias Ehmann,
         Carsten Miller,
         Alfred Wassermann
@@ -37,7 +37,8 @@ import JXG from "../jxg.js";
 import Type from "../utils/type.js";
 
 /**
- * @class Vector field.
+ * @class  A vector field on a plane can be visualized as a collection of arrows
+ * with given magnitudes and directions, each attached to a point on the plane.
  * <p>
  * Plot a vector field either given by two functions f1(x, y) and f2(x,y) or by a function f(x, y) returning an array of size 2.
  *
@@ -204,7 +205,7 @@ JXG.createVectorField = function (board, parents, attributes) {
 
     el.updateDataArray = function () {
         var x, y, i, j,
-            scale = Type.evaluate(this.visProp.scale),
+            scale = this.evalVisProp('scale'),
             start_x = Type.evaluate(this.xData[0]),
             steps_x = Type.evaluate(this.xData[1]),
             end_x = Type.evaluate(this.xData[2]),
@@ -216,16 +217,16 @@ JXG.createVectorField = function (board, parents, attributes) {
             delta_y = (end_y - start_y) / steps_y,
             v, theta, phi1, phi2,
 
-            showArrow = Type.evaluate(this.visProp.arrowhead.enabled),
+            showArrow = this.evalVisProp('arrowhead.enabled'),
             leg, leg_x, leg_y, alpha;
 
 
         if (showArrow) {
             // Arrow head style
-            leg = Type.evaluate(this.visProp.arrowhead.size);
+            leg = this.evalVisProp('arrowhead.size');
             leg_x = leg / board.unitX;
             leg_y = leg / board.unitY;
-            alpha = Type.evaluate(this.visProp.arrowhead.angle);
+            alpha = this.evalVisProp('arrowhead.angle');
         }
 
         this.dataX = [];
@@ -262,7 +263,8 @@ JXG.createVectorField = function (board, parents, attributes) {
 JXG.registerElement("vectorfield", JXG.createVectorField);
 
 /**
- * @class Slope field.
+ * @class A slope field is a graphical representation of the solutions
+ * to a first-order differential equation of a scalar function.
  * <p>
  * Plot a slope field given by a function f(x, y) returning a number.
  *
