@@ -62,10 +62,10 @@ JXG.JSXGraph = {
      * @type String
      */
     rendererType: (function () {
-        Options.board.renderer = "no";
+        Options.board.renderer = 'no';
 
         if (Env.supportsVML()) {
-            Options.board.renderer = "vml";
+            Options.board.renderer = 'vml';
             // Ok, this is some real magic going on here. IE/VML always was so
             // terribly slow, except in one place: Examples placed in a moodle course
             // was almost as fast as in other browsers. So i grabbed all the css and
@@ -92,21 +92,21 @@ JXG.JSXGraph = {
         }
 
         if (Env.supportsCanvas()) {
-            Options.board.renderer = "canvas";
+            Options.board.renderer = 'canvas';
         }
 
         if (Env.supportsSVG()) {
-            Options.board.renderer = "svg";
+            Options.board.renderer = 'svg';
         }
 
         // we are inside node
         if (Env.isNode() && Env.supportsCanvas()) {
-            Options.board.renderer = "canvas";
+            Options.board.renderer = 'canvas';
         }
 
-        if (Env.isNode() || Options.renderer === "no") {
-            Options.text.display = "internal";
-            Options.infobox.display = "internal";
+        if (Env.isNode() || Options.renderer === 'no') {
+            Options.text.display = 'internal';
+            Options.infobox.display = 'internal';
         }
 
         return Options.board.renderer;
@@ -129,7 +129,7 @@ JXG.JSXGraph = {
 
         // Former version:
         // doc = doc || document
-        if ((!Type.exists(doc) || doc === false) && typeof document === "object") {
+        if ((!Type.exists(doc) || doc === false) && typeof document === 'object') {
             doc = document;
         }
 
@@ -145,15 +145,15 @@ JXG.JSXGraph = {
         }
 
         // If attrRenderer is not supplied take the first available renderer
-        if (attrRenderer === undefined || attrRenderer === "auto") {
+        if (attrRenderer === undefined || attrRenderer === 'auto') {
             attrRenderer = this.rendererType;
         }
         // create the renderer
-        if (attrRenderer === "svg") {
+        if (attrRenderer === 'svg') {
             renderer = new SVGRenderer(boxid, dim);
-        } else if (attrRenderer === "vml") {
+        } else if (attrRenderer === 'vml') {
             renderer = new VMLRenderer(boxid);
-        } else if (attrRenderer === "canvas") {
+        } else if (attrRenderer === 'canvas') {
             renderer = new CanvasRenderer(boxid, dim);
         } else {
             renderer = new NoRenderer();
@@ -189,7 +189,7 @@ JXG.JSXGraph = {
             key = list[i];
             attr[key] = Type.copyAttributes(attr, options, 'board', key);
         }
-        attr.navbar = Type.copyAttributes(attr.navbar, options, "navbar");
+        attr.navbar = Type.copyAttributes(attr.navbar, options, 'navbar');
 
         // Treat moveTarget separately, because deepCopy will not work here.
         // Reason: moveTarget will be an HTML node and it is prevented that Type.deepCopy will copy it.
@@ -242,7 +242,7 @@ JXG.JSXGraph = {
             }
 
         node_jsx = (Type.isString(container)) ? doc.getElementById(container) : container;
-        node_jsx.setAttribute("role", "region");
+        node_jsx.setAttribute("role", 'region');
         node_jsx.setAttribute("aria-label", attr.title);              // set by initBoard( {title:})
 
         // doc_glob = node_jsx.ownerDocument; // This is the window.document element, needed below.
@@ -261,7 +261,7 @@ JXG.JSXGraph = {
         var node, id, doc;
 
         doc = board.document || document;
-        if (typeof doc !== "object") {
+        if (typeof doc !== 'object') {
             return;
         }
 
@@ -279,23 +279,213 @@ JXG.JSXGraph = {
 
     /**
      * Initialize a new board.
+     *
      * @param {String|Object} box id of or reference to the HTML element in which the board is painted.
-     * @param {Object} attributes An object that sets some of the board properties. Most of these properties can be set via JXG.Options.
-     * @param {Array} [attributes.boundingbox=[-5, 5, 5, -5]] An array containing four numbers describing the left, top, right and bottom boundary of the board in user coordinates
-     * @param {Boolean} [attributes.keepaspectratio=false] If <tt>true</tt>, the bounding box is adjusted to the same aspect ratio as the aspect ratio of the div containing the board.
-     * @param {Boolean} [attributes.showCopyright=false] Show the copyright string in the top left corner.
-     * @param {Boolean} [attributes.showNavigation=false] Show the navigation buttons in the bottom right corner.
-     * @param {Object} [attributes.zoom] Allow the user to zoom with the mouse wheel or the two-fingers-zoom gesture.
-     * @param {Object} [attributes.pan] Allow the user to pan with shift+drag mouse or two-fingers-pan gesture.
-     * @param {Object} [attributes.drag] Allow the user to drag objects with a pointer device.
-     * @param {Object} [attributes.keyboard] Allow the user to drag objects with arrow keys on keyboard.
-     * @param {Boolean} [attributes.axis=false] If set to true, show the axis. Can also be set to an object that is given to both axes as an attribute object.
-     * @param {Boolean|Object} [attributes.grid] If set to true, shows the grid. Can also be set to an object that is given to the grid as its attribute object.
-     * @param {Boolean} [attributes.registerEvents=true] Register mouse / touch events.
+     * @param {Object} attributes An object that sets some of the board properties.
+     * See {@link JXG.Board} for a list of available attributes of the board.
+     * Most of these attributes can also be set via {@link JXG.Options},
+     *
      * @returns {JXG.Board} Reference to the created board.
      *
      * @see JXG.AbstractRenderer#drawNavigationBar
+     * @example
+     * var board = JXG.JSXGraph.initBoard('jxgbox', {
+     *     boundingbox: [-10, 5, 10, -5],
+     *     keepaspectratio: false,
+     *     axis: true
+     * });
+     *
+     * </pre><div id="JXGc0f76e98-20bc-4224-9016-7ffa10770dff" class="jxgbox" style="width: 600px; height: 300px;"></div>
+     * <script type="text/javascript">
+     *     (function() {
+     *         var board = JXG.JSXGraph.initBoard('JXGc0f76e98-20bc-4224-9016-7ffa10770dff', {
+     *         boundingbox: [-10, 5, 10, -5],
+     *         keepaspectratio: false,
+     *         axis: true
+     *     });
+     *
+     *     })();
+     *
+     * </script><pre>
+     *
+     *
+     * @example
+     * const board = JXG.JSXGraph.initBoard('jxgbox', {
+     *   boundingbox: [-10, 10, 10, -10],
+     *   axis: true,
+     *   showCopyright: true,
+     *   showFullscreen: true,
+     *   showScreenshot: false,
+     *   showClearTraces: false,
+     *   showInfobox: false,
+     *   showNavigation: true,
+     *   grid: false,
+     *   defaultAxes: {
+     *     x: {
+     *       withLabel: true,
+     *       label: {
+     *         position: '95% left',
+     *         offset: [-10, 10]
+     *       },
+     *       lastArrow: {
+     *         type: 4,
+     *         size: 10
+     *       }
+     *     },
+     *     y: {
+     *       withLabel: true,
+     *       label: {
+     *         position: '0.90fr right',
+     *         offset: [6, -6]
+     *       },
+     *       lastArrow: {
+     *         type: 4,
+     *         size: 10
+     *       }
+     *     }
+     *   }
+     * });
+     *
+     * </pre><div id="JXG4ced167d-3235-48bc-84e9-1a28fce00f6a" class="jxgbox" style="width: 300px; height: 300px;"></div>
+     * <script type="text/javascript">
+     *     (function() {
+     *         var board = JXG.JSXGraph.initBoard('JXG4ced167d-3235-48bc-84e9-1a28fce00f6a', {
+     *       boundingbox: [-10, 10, 10, -10],
+     *       axis: true,
+     *       showCopyright: true,
+     *       showFullscreen: true,
+     *       showScreenshot: false,
+     *       showClearTraces: false,
+     *       showInfobox: false,
+     *       showNavigation: true,
+     *       grid: false,
+     *       defaultAxes: {
+     *         x: {
+     *           withLabel: true,
+     *           label: {
+     *             position: '95% left',
+     *             offset: [0, 0]
+     *           },
+     *           lastArrow: {
+     *             type: 4,
+     *             size: 10
+     *           }
+     *         },
+     *         y: {
+     *           withLabel: true,
+     *           label: {
+     *             position: '0.90fr right',
+     *             offset: [0, 0]
+     *           },
+     *           lastArrow: {
+     *             type: 4,
+     *             size: 10
+     *           }
+     *         }
+     *       }
+     *     });
+     *
+     *     })();
+     *
+     * </script><pre>
+     * @example
+     * const board = JXG.JSXGraph.initBoard('jxgbox', {
+     *     boundingbox: [-5, 5, 5, -5],
+     *     intl: {
+     *         enabled: false,
+     *         locale: 'en-EN'
+     *     },
+     *     keepaspectratio: true,
+     *     axis: true,
+     *     defaultAxes: {
+     *         x: {
+     *             ticks: {
+     *                 intl: {
+     *                         enabled: true,
+     *                         options: {
+     *                             style: 'unit',
+     *                             unit: 'kilometer-per-hour',
+     *                             unitDisplay: 'narrow'
+     *                         }
+     *                 }
+     *             }
+     *         },
+     *         y: {
+     *             ticks: {
+     *             }
+     *         }
+     *     },
+     *     infobox: {
+     *         fontSize: 20,
+     *         intl: {
+     *             enabled: true,
+     *             options: {
+     *                 minimumFractionDigits: 4,
+     *                 maximumFractionDigits: 5
+     *             }
+     *         }
+     *     }
+     * });
+     *
+     * </pre><div id="JXGdac54e59-f1e8-4fa6-bbcc-7486f7f6f960" class="jxgbox" style="width: 600px; height: 600px;"></div>
+     * <script type="text/javascript">
+     *     (function() {
+     *         var board = JXG.JSXGraph.initBoard('JXGdac54e59-f1e8-4fa6-bbcc-7486f7f6f960', {
+     *         boundingbox: [-5, 5, 5, -5],
+     *         intl: {
+     *             enabled: false,
+     *             locale: 'en-EN'
+     *         },
+     *         keepaspectratio: true,
+     *         axis: true,
+     *         defaultAxes: {
+     *             x: {
+     *                 ticks: {
+     *                     intl: {
+     *                             enabled: true,
+     *                             options: {
+     *                                 style: 'unit',
+     *                                 unit: 'kilometer-per-hour',
+     *                                 unitDisplay: 'narrow'
+     *                             }
+     *                     }
+     *                 }
+     *             },
+     *             y: {
+     *                 ticks: {
+     *                 }
+     *             }
+     *         },
+     *         infobox: {
+     *             fontSize: 20,
+     *             intl: {
+     *                 enabled: true,
+     *                 options: {
+     *                     minimumFractionDigits: 4,
+     *                     maximumFractionDigits: 5
+     *                 }
+     *             }
+     *         }
+     *     });
+     *
+     *     })();
+     *
+     * </script><pre>
+     *
+     *
      */
+    //  *
+    //  * @param {Array} [attributes.boundingbox=[-5, 5, 5, -5]] An array containing four numbers describing the left, top, right and bottom boundary of the board in user coordinates
+    //  * @param {Boolean} [attributes.keepaspectratio=false] If <tt>true</tt>, the bounding box is adjusted to the same aspect ratio as the aspect ratio of the div containing the board.
+    //  * @param {Boolean} [attributes.showCopyright=false] Show the copyright string in the top left corner.
+    //  * @param {Boolean} [attributes.showNavigation=false] Show the navigation buttons in the bottom right corner.
+    //  * @param {Object} [attributes.zoom] Allow the user to zoom with the mouse wheel or the two-fingers-zoom gesture.
+    //  * @param {Object} [attributes.pan] Allow the user to pan with shift+drag mouse or two-fingers-pan gesture.
+    //  * @param {Object} [attributes.drag] Allow the user to drag objects with a pointer device.
+    //  * @param {Object} [attributes.keyboard] Allow the user to drag objects with arrow keys on keyboard.
+    //  * @param {Boolean} [attributes.axis=false] If set to true, show the axis. Can also be set to an object that is given to both axes as an attribute object.
+    //  * @param {Boolean|Object} [attributes.grid] If set to true, shows the grid. Can also be set to an object that is given to the grid as its attribute object.
+    //  * @param {Boolean} [attributes.registerEvents=true] Register mouse / touch events.
     initBoard: function (box, attributes) {
         var originX, originY, unitX, unitY, w, h,
             offX = 0, offY = 0,
@@ -543,7 +733,7 @@ JXG.JSXGraph = {
     freeBoard: function (board) {
         var el;
 
-        if (typeof board === "string") {
+        if (typeof board === 'string') {
             board = JXG.boards[board];
         }
 
@@ -602,7 +792,7 @@ if (Env.isBrowser && typeof window === 'object' && typeof document === 'object')
                 cssClasses, bbox, axis, grid, code, src, request,
                 postpone = false,
 
-                scripts = document.getElementsByTagName("script"),
+                scripts = document.getElementsByTagName('script'),
                 init = function (code, type, bbox) {
                     var board = JXG.JSXGraph.initBoard(id, {
                         boundingbox: bbox,
@@ -612,7 +802,7 @@ if (Env.isBrowser && typeof window === 'object' && typeof document === 'object')
                         showReload: true
                     });
 
-                    if (type.toLowerCase().indexOf("script") > -1) {
+                    if (type.toLowerCase().indexOf('script') > -1) {
                         board.construct(code);
                     } else {
                         try {
@@ -642,7 +832,7 @@ if (Env.isBrowser && typeof window === 'object' && typeof document === 'object')
                     (type.toLowerCase() === "text/jessiescript" ||
                         type.toLowerCase() === "jessiescript" ||
                         type.toLowerCase() === "text/jessiecode" ||
-                        type.toLowerCase() === "jessiecode")
+                        type.toLowerCase() === 'jessiecode')
                 ) {
                     cssClasses = scripts[i].getAttribute("class", false) || "";
                     width = scripts[i].getAttribute("width", false) || "";
@@ -661,12 +851,12 @@ if (Env.isBrowser && typeof window === 'object' && typeof document === 'object')
                             bbox[j] = parseFloat(bbox[j]);
                         }
                     }
-                    axis = Type.str2Bool(scripts[i].getAttribute("axis", false) || "false");
-                    grid = Type.str2Bool(scripts[i].getAttribute("grid", false) || "false");
+                    axis = Type.str2Bool(scripts[i].getAttribute("axis", false) || 'false');
+                    grid = Type.str2Bool(scripts[i].getAttribute("grid", false) || 'false');
 
                     if (!Type.exists(id)) {
                         id = "jessiescript_autgen_jxg_" + i;
-                        div = document.createElement("div");
+                        div = document.createElement('div');
                         div.setAttribute("id", id);
 
                         txt = width !== "" ? "width:" + width + ";" : "";
@@ -680,7 +870,7 @@ if (Env.isBrowser && typeof window === 'object' && typeof document === 'object')
                             document.body.insertBefore(div, scripts[i]);
                         } catch (e) {
                             // there's probably jquery involved...
-                            if (typeof jQuery === "object") {
+                            if (Type.exists(jQuery) && typeof jQuery === 'object') {
                                 jQuery(div).insertBefore(scripts[i]);
                             }
                         }
