@@ -243,7 +243,7 @@ JXG.extend(MatInterval.prototype, {
     },
 
     assign: function (lo, hi) {
-        if (typeof lo !== "number" || typeof hi !== "number") {
+        if (typeof lo !== "number" || typeof hi !== 'number') {
             throw new TypeError("JXG.Math.Interval#assign: arguments must be numbers");
         }
         if (isNaN(lo) || isNaN(hi) || lo > hi) {
@@ -285,7 +285,9 @@ JXG.extend(MatInterval.prototype, {
  * Object for interval arithmetics.
  * @name JXG.Math.IntervalArithmetic
  * @namespace
+ * @exports Mat.IntervalArithmetic as JXG.Math.IntervalArithmetic
  *
+ * @description
  * Interval arithmetic is a technique used to mitigate rounding and measurement errors in mathematical computation
  * by computing function bounds. Instead of representing a value as a single number, interval arithmetic represents each value as a range.
  * <br><br>
