@@ -539,10 +539,12 @@ Type.extend(
          */
         tracing: function (u0, direction) {
             var u = [],
+                ulast = [],
+                len,
                 v = [],
                 v_start = [],
                 w = [],
-                t_u, t_v, t_u_0,
+                t_u, t_v, t_u_0, tloc,
                 A,
                 grad,
                 nrm,
@@ -616,7 +618,7 @@ Type.extend(
                         Mat.innerProduct(t_u, t_u_0, 2) > this.config.loop_dir
                     ) {
 
-                        // console.log("Loop detected after", steps, "steps");
+                        // console.log("Loop detected after", steps, 'steps');
                         // console.log("\t", "v", v, "u0:", u0)
                         // console.log("\t", "Dist(v, path0)", dist, config.loop_dist * h)
                         // console.log("\t", "t_u", t_u);
@@ -679,12 +681,12 @@ Type.extend(
                 // Predictor step
                 // if (true /*h < 2 * this.config.h_initial*/) {
                 // Euler
-                // console.log("euler")
+                // console.log('euler')
                 v[0] = u[0] + h * omega * t_u[0];
                 v[1] = u[1] + h * omega * t_u[1];
                 // } else {
                 //     // Heun
-                //     // console.log("heun")
+                //     // console.log('heun')
                 //     v[0] = u[0] + h * omega * t_u[0];
                 //     v[1] = u[1] + h * omega * t_u[1];
 
@@ -821,6 +823,54 @@ Type.extend(
                 u[1] >= this.bbox[3]
             );
 
+            // Clipping to bounding box, last may be outside, interpolate between second last und last point
+            len = pathX.length;
+            ulast = [pathX[len - 2], pathY[len - 2]];
+
+            // If u[0] is outside x-interval in bounding box, interpolate to the box.
+            if (u[0] < this.bbox[0]) {
+                if (u[0] !== ulast[0]) {
+                    tloc = (this.bbox[0] - ulast[0]) / (u[0] - ulast[0]);
+                    if (u[1] !== ulast[1]) {
+                        u[1] = ulast[1] + tloc * (u[1] - ulast[1]);
+                    }
+                }
+                u[0] = this.bbox[0];
+            }
+            if (u[0] > this.bbox[2]) {
+                if (u[0] !== ulast[0]) {
+                    tloc = (this.bbox[2] - ulast[0]) / (u[0] - ulast[0]);
+                    if (u[1] !== ulast[1]) {
+                        u[1] = ulast[1] + tloc * (u[1] - ulast[1]);
+                    }
+                }
+                u[0] = this.bbox[2];
+            }
+
+            // If u[1] is outside y-interval in bounding box, interpolate to the box.
+            if (u[1] < this.bbox[3]) {
+                if (u[1] !== ulast[1]) {
+                    tloc = (this.bbox[3] - ulast[1]) / (u[1] - ulast[1]);
+                    if (u[0] !== ulast[0]) {
+                        u[0] = ulast[0] + tloc * (u[0] - ulast[0]);
+                    }
+                }
+                u[1] = this.bbox[3];
+            }
+            if (u[1] > this.bbox[1]) {
+                if (u[1] !== ulast[1]) {
+                    tloc = (this.bbox[1] - ulast[1]) / (u[1] - ulast[1]);
+                    if (u[0] !== ulast[0]) {
+                        u[0] = ulast[0] + tloc * (u[0] - ulast[0]);
+                    }
+                }
+                u[1] = this.bbox[1];
+            }
+
+            // Update last point
+            pathX[len - 1] = u[0];
+            pathY[len - 1] = u[1];
+
             // if (!loop_closed) {
             //     console.log("No loop", steps);
             // } else {
