@@ -59,11 +59,11 @@
                 this.board.unitX = 30;
                 this.board.unitY = 30;
 
-                this.readElements(this.tree.getElementsByTagName("elements"));
-                this.readConstraints(this.tree.getElementsByTagName("constraints"));
+                this.readElements(this.tree.getElementsByTagName('elements'));
+                this.readConstraints(this.tree.getElementsByTagName('constraints'));
                 this.cleanUp();
                 this.board.fullUpdate();
-                this.readDisplay(this.tree.getElementsByTagName("display"));
+                this.readDisplay(this.tree.getElementsByTagName('display'));
                 this.board.fullUpdate();
             },
 
@@ -77,7 +77,7 @@
                     return;
                 }
 
-                if (node.nodeName === "point") {
+                if (node.nodeName === 'point') {
                     this.storePoint(node);
                 } else if (
                     node.nodeName === "line" ||
@@ -86,15 +86,15 @@
                     node.nodeName === "vector"
                 ) {
                     this.storeLine(node);
-                } else if (node.nodeName === "circle") {
+                } else if (node.nodeName === 'circle') {
                     this.storeConic(node);
-                } else if (node.nodeName === "conic") {
+                } else if (node.nodeName === 'conic') {
                     this.storeConic(node);
                     //} else if (node.nodeName === 'polygon') {
                     // ignore, see this.addPolygonByVertices
                 } else {
                     JXG.debug(
-                        "Not implemented: " + node.nodeName + " " + node.getAttribute("id")
+                        "Not implemented: " + node.nodeName + " " + node.getAttribute('id')
                     );
                 }
             },
@@ -130,12 +130,12 @@
                 if (p.nodeName === "homogeneous_coordinates") {
                     for (j = 0; j < p.childNodes.length; j++) {
                         if (p.childNodes[j].nodeType === 1) {
-                            if (p.childNodes[j].nodeName === "double") {
+                            if (p.childNodes[j].nodeName === 'double') {
                                 // content of <double>...</double>
                                 c.push(p.childNodes[j].firstChild.data);
-                            } else if (p.childNodes[j].nodeName === "complex") {
+                            } else if (p.childNodes[j].nodeName === 'complex') {
                                 for (l = 0; l < p.childNodes[j].childNodes.length; l++) {
-                                    if (p.childNodes[j].childNodes[l].nodeName === "double") {
+                                    if (p.childNodes[j].childNodes[l].nodeName === 'double') {
                                         c.push(p.childNodes[j].childNodes[l].firstChild.data);
                                     }
                                 }
@@ -197,14 +197,14 @@
                     return;
                 }
 
-                this.objects[node.getAttribute("id")] = {
-                    id: node.getAttribute("id"),
+                this.objects[node.getAttribute('id')] = {
+                    id: node.getAttribute('id'),
                     coords: null
                 };
-                this.objects[node.getAttribute("id")].coords = parents;
-                this.objects[node.getAttribute("id")].id = node.getAttribute("id");
-                this.objects[node.getAttribute("id")].exists = false;
-                this.objects[node.getAttribute("id")].i2geoType = "point";
+                this.objects[node.getAttribute('id')].coords = parents;
+                this.objects[node.getAttribute('id')].id = node.getAttribute('id');
+                this.objects[node.getAttribute('id')].exists = false;
+                this.objects[node.getAttribute('id')].i2geoType = 'point'
             },
 
             /**
@@ -215,8 +215,8 @@
             storeLine: function (node) {
                 var i, p, c, j;
 
-                this.objects[node.getAttribute("id")] = {
-                    id: node.getAttribute("id"),
+                this.objects[node.getAttribute('id')] = {
+                    id: node.getAttribute('id'),
                     coords: null
                 };
                 i = 0;
@@ -232,19 +232,19 @@
                     c = [];
                     for (j = 0; j < p.childNodes.length; j++) {
                         if (p.childNodes[j].nodeType === 1) {
-                            if (p.childNodes[j].nodeName === "double") {
+                            if (p.childNodes[j].nodeName === 'double') {
                                 // content of <double>...</double>
                                 c.push(parseFloat(p.childNodes[j].firstChild.data));
                             }
                             // else {
-                            //    $('debug').innerHTML += 'Not: '+ p.childNodes[j].nodeName + '<br>';  // <complex>
+                            //    $('debug').innerText += 'Not: '+ p.childNodes[j].nodeName + '\n';  // <complex>
                             //}
                         }
                     }
-                    this.objects[node.getAttribute("id")].coords = c;
-                    this.objects[node.getAttribute("id")].id = node.getAttribute("id");
-                    this.objects[node.getAttribute("id")].exists = false;
-                    this.objects[node.getAttribute("id")].i2geoType = "line";
+                    this.objects[node.getAttribute('id')].coords = c;
+                    this.objects[node.getAttribute('id')].id = node.getAttribute('id');
+                    this.objects[node.getAttribute('id')].exists = false;
+                    this.objects[node.getAttribute('id')].i2geoType = 'line'
                 }
             },
 
@@ -271,8 +271,8 @@
             storeConic: function (node) {
                 var i, j, p, c;
 
-                this.objects[node.getAttribute("id")] = {
-                    id: node.getAttribute("id"),
+                this.objects[node.getAttribute('id')] = {
+                    id: node.getAttribute('id'),
                     coords: null
                 };
                 i = 0;
@@ -284,24 +284,24 @@
                     p = node.childNodes[i];
                 }
 
-                if (p.nodeName === "matrix") {
+                if (p.nodeName === 'matrix') {
                     c = [];
 
                     for (j = 0; j < p.childNodes.length; j++) {
                         if (p.childNodes[j].nodeType === 1) {
-                            if (p.childNodes[j].nodeName === "double") {
+                            if (p.childNodes[j].nodeName === 'double') {
                                 // content of <double>...</double>
                                 c.push(parseFloat(p.childNodes[j].firstChild.data));
                             }
                             //else {
-                            //    $('debug').innerHTML += 'Not: '+ p.childNodes[j].nodeName + '<br>';  // <complex>
+                            //    $('debug').innerText += 'Not: '+ p.childNodes[j].nodeName + '\n';  // <complex>
                             //}
                         }
                     }
-                    this.objects[node.getAttribute("id")].coords = c;
-                    this.objects[node.getAttribute("id")].id = node.getAttribute("id");
-                    this.objects[node.getAttribute("id")].exists = false;
-                    this.objects[node.getAttribute("id")].i2geoType = "conic";
+                    this.objects[node.getAttribute('id')].coords = c;
+                    this.objects[node.getAttribute('id')].id = node.getAttribute('id');
+                    this.objects[node.getAttribute('id')].exists = false;
+                    this.objects[node.getAttribute('id')].i2geoType = 'conic'
                 }
             },
 
@@ -354,7 +354,7 @@
                     this.addAngularBisectorsOfTwoLines(node);
                 } else if (node.nodeName === "midpoint_of_two_points") {
                     this.addMidpointOfTwoPoints(node);
-                } else if (node.nodeName === "midpoint") {
+                } else if (node.nodeName === 'midpoint') {
                     this.addMidpointOfTwoPoints(node);
                 } else if (
                     node.nodeName === "midpoint_of_line_segment" ||
@@ -405,8 +405,8 @@
                 var s;
 
                 // Set the default colors of dependent elements
-                this.board.options.point.strokeColor = "blue";
-                this.board.options.point.fillColor = "blue";
+                this.board.options.point.strokeColor = 'blue'
+                this.board.options.point.fillColor = 'blue'
 
                 for (s = 0; s < tree[0].childNodes.length; s++) {
                     this.readConstraint(tree, s);
@@ -484,11 +484,11 @@
                 for (p in this.objects) {
                     if (this.objects.hasOwnProperty(p)) {
                         if (this.objects[p].exists === false) {
-                            if (this.objects[p].i2geoType === "point") {
+                            if (this.objects[p].i2geoType === 'point') {
                                 this.addPoint(this.objects[p]);
-                            } else if (this.objects[p].i2geoType === "line") {
+                            } else if (this.objects[p].i2geoType === 'line') {
                                 this.addLine(this.objects[p]);
-                            } else if (this.objects[p].i2geoType === "conic") {
+                            } else if (this.objects[p].i2geoType === 'conic') {
                                 this.addConic(this.objects[p]);
                             } else {
                                 JXG.debug(
@@ -1080,43 +1080,43 @@
 
                 if (node.nodeName === "background-color") {
                     this.board.containerObj.style.backgroundColor = node.firstChild.data;
-                } else if (node.nodeName === "style") {
+                } else if (node.nodeName === 'style') {
                     // get the element
-                    el = this.board.select(node.getAttribute("ref"));
+                    el = this.board.select(node.getAttribute('ref'));
 
                     for (j = 0; j < node.childNodes.length; j++) {
                         if (node.childNodes[j].nodeType === 1) {
                             key = node.childNodes[j].nodeName;
                             val = node.childNodes[j].firstChild.data;
-                            if (key === "stroke") {
-                                key = "strokeColor";
+                            if (key === 'stroke') {
+                                key = 'strokeColor'
                             } else if (key === "stroke-width" || key === "border-width") {
-                                key = "strokeWidth";
-                            } else if (key === "fill") {
-                                key = "fillColor";
+                                key = 'strokeWidth'
+                            } else if (key === 'fill') {
+                                key = 'fillColor'
                             } else if (key === "fill-opacity") {
-                                key = "fillOpacity";
+                                key = 'fillOpacity'
                             } else if (key === "border-opacity") {
-                                key = "strokeOpacity";
+                                key = 'strokeOpacity'
                             } else if (key === "point-size") {
-                                key = "size";
-                            } else if (key === "label") {
-                                key = "name";
+                                key = 'size'
+                            } else if (key === 'label') {
+                                key = 'name'
                             } else if (key === "point-style") {
-                                key = "face";
-                                if (val === "circle") {
-                                    val = "o";
-                                } else if (val === "cross") {
+                                key = 'face'
+                                if (val === 'circle') {
+                                    val = 'o'
+                                } else if (val === 'cross') {
                                     val = "+";
                                 } else if (val === "x-mark") {
-                                    val = "x";
-                                } else if (val === "square") {
+                                    val = 'x'
+                                } else if (val === 'square') {
                                     val = "[]";
-                                } else if (val === "triangle") {
-                                    val = "triangleup";
-                                } else if (val === "point") {
+                                } else if (val === 'triangle') {
+                                    val = 'triangleup'
+                                } else if (val === 'point') {
                                     // Setting size to 1 is missing
-                                    val = "o";
+                                    val = 'o'
                                 } else {
                                     JXG.debug("Display: not implemented" + node.nodeName);
                                     // Missing:
