@@ -55,10 +55,10 @@ JXG.SVGRenderer = function (container, dim) {
     var i;
 
     // docstring in AbstractRenderer
-    this.type = "svg";
+    this.type = 'svg';
 
     this.isIE =
-        navigator.appVersion.indexOf("MSIE") !== -1 || navigator.userAgent.match(/Trident\//);
+        navigator.appVersion.indexOf('MSIE') !== -1 || navigator.userAgent.match(/Trident\//);
 
     /**
      * SVG root node
@@ -87,17 +87,17 @@ JXG.SVGRenderer = function (container, dim) {
     this.container = container;
 
     // prepare the div container and the svg root node for use with JSXGraph
-    this.container.style.MozUserSelect = "none";
-    this.container.style.userSelect = "none";
+    this.container.style.MozUserSelect = 'none';
+    this.container.style.userSelect = 'none';
 
-    this.container.style.overflow = "hidden";
+    this.container.style.overflow = 'hidden';
     if (this.container.style.position === "") {
-        this.container.style.position = "relative";
+        this.container.style.position = 'relative';
     }
 
-    this.svgRoot = this.container.ownerDocument.createElementNS(this.svgNamespace, "svg");
-    this.svgRoot.style.overflow = "hidden";
-    this.svgRoot.style.display = "block";
+    this.svgRoot = this.container.ownerDocument.createElementNS(this.svgNamespace, 'svg');
+    this.svgRoot.style.overflow = 'hidden';
+    this.svgRoot.style.display = 'block';
     this.resize(dim.width, dim.height);
 
     //this.svgRoot.setAttributeNS(null, 'shape-rendering', 'crispEdge'); //'optimizeQuality'); //geometricPrecision');
@@ -109,7 +109,7 @@ JXG.SVGRenderer = function (container, dim) {
      * @type Node
      * @see https://www.w3.org/TR/SVG2/struct.html#DefsElement
      */
-    this.defs = this.container.ownerDocument.createElementNS(this.svgNamespace, "defs");
+    this.defs = this.container.ownerDocument.createElementNS(this.svgNamespace, 'defs');
     this.svgRoot.appendChild(this.defs);
 
     /**
@@ -264,7 +264,7 @@ JXG.SVGRenderer = function (container, dim) {
             this.svgNamespace,
             "foreignObject"
         );
-        this.foreignObjLayer.setAttribute("display", "none");
+        this.foreignObjLayer.setAttribute("display", 'none');
         this.foreignObjLayer.setAttribute("x", 0);
         this.foreignObjLayer.setAttribute("y", 0);
         this.foreignObjLayer.setAttribute("width", "100%");
@@ -313,21 +313,18 @@ JXG.extend(
             if (Type.exists(type)) {
                 id += type;
             }
-            node2 = this.createPrim("marker", id);
+            node2 = this.createPrim('marker', id);
 
-            node2.setAttributeNS(null, "stroke", el.evalVisProp('strokecolor'));
-            node2.setAttributeNS(
-                null,
-                "stroke-opacity",
-                el.evalVisProp('strokeopacity')
-            );
-            node2.setAttributeNS(null, "fill", el.evalVisProp('strokecolor'));
-            node2.setAttributeNS(null, "fill-opacity", el.evalVisProp('strokeopacity'));
-            node2.setAttributeNS(null, "stroke-width", 0); // this is the stroke-width of the arrow head.
+            // 'context-stroke': property is inherited from line or curve
+            node2.setAttributeNS(null, 'fill', 'context-stroke');
+            node2.setAttributeNS(null, 'stroke', 'context-stroke');
+            // node2.setAttributeNS(null, 'fill-opacity', 'context-stroke'); // Not available
+            // node2.setAttributeNS(null, 'stroke-opacity', 'context-stroke');
+            node2.setAttributeNS(null, 'stroke-width', 0); // this is the stroke-width of the arrow head.
             // Should be zero to simplify the calculations
 
-            node2.setAttributeNS(null, "orient", "auto");
-            node2.setAttributeNS(null, "markerUnits", "strokeWidth"); // 'strokeWidth' 'userSpaceOnUse');
+            node2.setAttributeNS(null, 'orient', 'auto');
+            node2.setAttributeNS(null, 'markerUnits', 'strokeWidth'); // 'strokeWidth' 'userSpaceOnUse');
 
             /*
                Types 1, 2:
@@ -352,9 +349,9 @@ JXG.extend(
                arrow head and line. This is not the case for curves, yet.
                Therefore, the offset refX has to be adapted to the path type.
             */
-            node3 = this.container.ownerDocument.createElementNS(this.svgNamespace, "path");
+            node3 = this.container.ownerDocument.createElementNS(this.svgNamespace, 'path');
             h = 5;
-            if (idAppendix === "Start") {
+            if (idAppendix === 'Start') {
                 // First arrow
                 v = 0;
                 if (type === 2) {
@@ -475,11 +472,12 @@ JXG.extend(
                 }
             }
             if (type === 7) {
-                node2.setAttributeNS(null, "fill", "none");
-                node2.setAttributeNS(null, "stroke-width", 1); // this is the stroke-width of the arrow head.
+                node2.setAttributeNS(null, 'fill', 'none');
+                node2.setAttributeNS(null, 'stroke-width', 1); // this is the stroke-width of the arrow head.
             }
             node2.setAttributeNS(null, "refY", h);
             node2.setAttributeNS(null, "refX", v);
+            // this.setPropertyPrim(node2, 'class', el.evalVisProp('cssclass'));
 
             node2.appendChild(node3);
             return node2;
@@ -497,16 +495,15 @@ JXG.extend(
                 if (Type.isString(color)) {
                     if (type !== 7) {
                         this._setAttribute(function () {
-                            node.setAttributeNS(null, "stroke", color);
-                            node.setAttributeNS(null, "fill", color);
-                            node.setAttributeNS(null, "stroke-opacity", opacity);
-                            node.setAttributeNS(null, "fill-opacity", opacity);
+                            node.setAttributeNS(null, 'fill', 'context-stroke');
+                            // node.setAttributeNS(null, 'stroke-opacity', 'context-stroke');
+                            // node.setAttributeNS(null, 'fill-opacity', 'context-stroke');
                         }, el.visPropOld.fillcolor);
                     } else {
                         this._setAttribute(function () {
-                            node.setAttributeNS(null, "fill", "none");
-                            node.setAttributeNS(null, "stroke", color);
-                            node.setAttributeNS(null, "stroke-opacity", opacity);
+                            node.setAttributeNS(null, 'fill', 'none');
+                            node.setAttributeNS(null, 'stroke', 'context-stroke');
+                            // node.setAttributeNS(null, 'stroke-opacity', 'context-stroke');
                         }, el.visPropOld.fillcolor);
                     }
                 }
@@ -532,7 +529,7 @@ JXG.extend(
                 node.setAttributeNS(null, "viewBox", 0 + " " + 0 + " " + s * 10 + " " + s * 10);
                 node.setAttributeNS(null, "markerHeight", d);
                 node.setAttributeNS(null, "markerWidth", d);
-                node.setAttributeNS(null, "display", "inherit");
+                node.setAttributeNS(null, "display", 'inherit');
                 // }
 
                 // if (this.isIE) {
@@ -589,14 +586,10 @@ JXG.extend(
             }
 
             node.setAttributeNS(null, "stroke", ticks.evalVisProp('strokecolor'));
-            node.setAttributeNS(null, "fill", "none");
+            node.setAttributeNS(null, "fill", 'none');
             // node.setAttributeNS(null, 'fill', ticks.evalVisProp('fillcolor'));
             // node.setAttributeNS(null, 'fill-opacity', ticks.evalVisProp('fillopacity'));
-            node.setAttributeNS(
-                null,
-                "stroke-opacity",
-                ticks.evalVisProp('strokeopacity')
-            );
+            node.setAttributeNS(null, 'stroke-opacity', ticks.evalVisProp('strokeopacity'));
             node.setAttributeNS(null, "stroke-width", ticks.evalVisProp('strokewidth'));
             this.updatePathPrim(node, tickStr, ticks.board);
         },
@@ -634,7 +627,7 @@ JXG.extend(
             node.setAttributeNS(null, 'y', '5px');
             node.setAttributeNS(null, 'width', s + 'px');
             node.setAttributeNS(null, 'height', s + 'px');
-            node.setAttributeNS(null, "preserveAspectRatio", "none");
+            node.setAttributeNS(null, "preserveAspectRatio", 'none');
             node.setAttributeNS(null, 'style', 'opacity:' + alpha + ';');
             node.setAttributeNS(null, 'aria-hidden', 'true');
 
@@ -648,8 +641,8 @@ JXG.extend(
 
             //node.setAttributeNS(null, "style", "alignment-baseline:middle"); // Not yet supported by Firefox
             // Preserve spaces
-            //node.setAttributeNS("http://www.w3.org/XML/1998/namespace", "space", "preserve");
-            node.style.whiteSpace = "nowrap";
+            //node.setAttributeNS("http://www.w3.org/XML/1998/namespace", "space", 'preserve');
+            node.style.whiteSpace = 'nowrap';
 
             el.rendNodeText = this.container.ownerDocument.createTextNode("");
             node.appendChild(el.rendNodeText);
@@ -666,7 +659,7 @@ JXG.extend(
                 ev_ay = el.getAnchorY();
 
             css = el.evalVisProp('cssclass');
-            if (el.rendNode.getAttributeNS(null, "class") !== css) {
+            if (el.rendNode.getAttributeNS(null, 'class') !== css) {
                 el.rendNode.setAttributeNS(null, "class", css);
                 el.needsSizeUpdate = true;
             }
@@ -675,14 +668,14 @@ JXG.extend(
                 // Horizontal
                 v = el.coords.scrCoords[1];
                 if (el.visPropOld.left !== ev_ax + v) {
-                    el.rendNode.setAttributeNS(null, "x", v + "px");
+                    el.rendNode.setAttributeNS(null, "x", v + 'px');
 
-                    if (ev_ax === "left") {
-                        el.rendNode.setAttributeNS(null, "text-anchor", "start");
-                    } else if (ev_ax === "right") {
-                        el.rendNode.setAttributeNS(null, "text-anchor", "end");
-                    } else if (ev_ax === "middle") {
-                        el.rendNode.setAttributeNS(null, "text-anchor", "middle");
+                    if (ev_ax === 'left') {
+                        el.rendNode.setAttributeNS(null, "text-anchor", 'start');
+                    } else if (ev_ax === 'right') {
+                        el.rendNode.setAttributeNS(null, "text-anchor", 'end');
+                    } else if (ev_ax === 'middle') {
+                        el.rendNode.setAttributeNS(null, "text-anchor", 'middle');
                     }
                     el.visPropOld.left = ev_ax + v;
                 }
@@ -690,26 +683,26 @@ JXG.extend(
                 // Vertical
                 v = el.coords.scrCoords[2];
                 if (el.visPropOld.top !== ev_ay + v) {
-                    el.rendNode.setAttributeNS(null, "y", v + this.vOffsetText * 0.5 + "px");
+                    el.rendNode.setAttributeNS(null, "y", v + this.vOffsetText * 0.5 + 'px');
 
                     // Not supported by IE, edge
-                    // el.rendNode.setAttributeNS(null, "dy", "0");
-                    // if (ev_ay === "bottom") {
+                    // el.rendNode.setAttributeNS(null, "dy", '0');
+                    // if (ev_ay === 'bottom') {
                     //     el.rendNode.setAttributeNS(null, 'dominant-baseline', 'text-after-edge');
-                    // } else if (ev_ay === "top") {
+                    // } else if (ev_ay === 'top') {
                     //     el.rendNode.setAttributeNS(null, 'dominant-baseline', 'text-before-edge');
-                    // } else if (ev_ay === "middle") {
+                    // } else if (ev_ay === 'middle') {
                     //     el.rendNode.setAttributeNS(null, 'dominant-baseline', 'middle');
                     // }
 
-                    if (ev_ay === "bottom") {
-                        el.rendNode.setAttributeNS(null, "dy", "0");
+                    if (ev_ay === 'bottom') {
+                        el.rendNode.setAttributeNS(null, "dy", '0');
                         el.rendNode.setAttributeNS(null, 'dominant-baseline', 'auto');
-                    } else if (ev_ay === "top") {
-                        el.rendNode.setAttributeNS(null, "dy", "1.6ex");
+                    } else if (ev_ay === 'top') {
+                        el.rendNode.setAttributeNS(null, "dy", '1.6ex');
                         el.rendNode.setAttributeNS(null, 'dominant-baseline', 'auto');
-                    } else if (ev_ay === "middle") {
-                        el.rendNode.setAttributeNS(null, "dy", "0.6ex");
+                    } else if (ev_ay === 'middle') {
+                        el.rendNode.setAttributeNS(null, "dy", '0.6ex');
                         el.rendNode.setAttributeNS(null, 'dominant-baseline', 'auto');
                     }
                     el.visPropOld.top = ev_ay + v;
@@ -738,7 +731,7 @@ JXG.extend(
         drawImage: function (el) {
             var node = this.createPrim("image", el.id);
 
-            node.setAttributeNS(null, "preserveAspectRatio", "none");
+            node.setAttributeNS(null, "preserveAspectRatio", 'none');
             this.appendChildPrim(node, el.evalVisProp('layer'));
             el.rendNode = node;
 
@@ -810,16 +803,16 @@ JXG.extend(
                 el.evalVisProp('layer')
             );
 
-            this.appendNodesToElement(el, "foreignObject");
+            this.appendNodesToElement(el, 'foreignObject');
             this.updateForeignObject(el);
         },
 
         // Already documented in JXG.AbstractRenderer
         updateForeignObject: function (el) {
             if (el._useUserSize) {
-                el.rendNode.style.overflow = "hidden";
+                el.rendNode.style.overflow = 'hidden';
             } else {
-                el.rendNode.style.overflow = "visible";
+                el.rendNode.style.overflow = 'visible';
             }
 
             this.updateRectPrim(
@@ -856,11 +849,11 @@ JXG.extend(
         createPrim: function (type, id) {
             var node = this.container.ownerDocument.createElementNS(this.svgNamespace, type);
             node.setAttributeNS(null, "id", this.uniqName(id));
-            node.style.position = "absolute";
-            if (type === "path") {
-                node.setAttributeNS(null, "stroke-linecap", "round");
-                node.setAttributeNS(null, "stroke-linejoin", "round");
-                node.setAttributeNS(null, "fill-rule", "evenodd");
+            node.style.position = 'absolute';
+            if (type === 'path') {
+                node.setAttributeNS(null, "stroke-linecap", 'round');
+                node.setAttributeNS(null, "stroke-linejoin", 'round');
+                node.setAttributeNS(null, "fill-rule", 'evenodd');
             }
 
             return node;
@@ -914,14 +907,15 @@ JXG.extend(
                         this.defs.appendChild(node2);
                     }
                     el.rendNodeTriangleStart = node2;
-                    el.rendNode.setAttributeNS(null, "marker-start", this.toURL(str));
+                    el.rendNode.setAttributeNS(null, 'marker-start', this.toURL(str));
                 }
             } else {
                 if (Type.exists(node2)) {
                     this.remove(node2);
                     el.rendNodeTriangleStart = null;
                 }
-                el.rendNode.setAttributeNS(null, "marker-start", null);
+                // el.rendNode.setAttributeNS(null, "marker-start", null);
+                el.rendNode.removeAttributeNS(null, 'marker-start');
             }
 
             node2 = el.rendNodeTriangleEnd;
@@ -945,7 +939,8 @@ JXG.extend(
                     this.remove(node2);
                     el.rendNodeTriangleEnd = null;
                 }
-                el.rendNode.setAttributeNS(null, "marker-end", null);
+                // el.rendNode.setAttributeNS(null, "marker-end", null);
+                el.rendNode.removeAttributeNS(null, "marker-end");
             }
         },
 
@@ -1002,7 +997,7 @@ JXG.extend(
                 sqrt32 = size * Math.sqrt(3) * 0.5,
                 s05 = size * 0.5;
 
-            if (type === "x") {
+            if (type === 'x') {
                 s =
                     " M " +
                     (scr[1] - size) +
@@ -1095,7 +1090,7 @@ JXG.extend(
                     " " +
                     (scr[2] + s05) +
                     " Z "; // close path
-            } else if (type === "v") {
+            } else if (type === 'v') {
                 s =
                     " M " +
                     scr[1] +
@@ -1216,7 +1211,7 @@ JXG.extend(
                 maxSize = 5000.0,
                 pStr = "",
                 f = el.evalVisProp('strokewidth'),
-                isNoPlot = el.evalVisProp('curvetype') !== "plot";
+                isNoPlot = el.evalVisProp('curvetype') !== 'plot';
 
             if (el.numberPoints <= 0) {
                 return "";
@@ -1278,9 +1273,9 @@ JXG.extend(
                 scrCoords,
                 len = el.vertices.length;
 
-            node.setAttributeNS(null, "stroke", "none");
-            node.setAttributeNS(null, "fill-rule", "evenodd");
-            if (el.elType === "polygonalchain") {
+            node.setAttributeNS(null, "stroke", 'none');
+            node.setAttributeNS(null, "fill-rule", 'evenodd');
+            if (el.elType === 'polygonalchain') {
                 len++;
             }
 
@@ -1297,7 +1292,7 @@ JXG.extend(
                     pStr += " ";
                 }
             }
-            if (pStr.indexOf("NaN") === -1) {
+            if (pStr.indexOf('NaN') === -1) {
                 node.setAttributeNS(null, "points", pStr);
             }
         },
@@ -1346,11 +1341,11 @@ JXG.extend(
                 el.visPropOld.visible = val;
                 node = el.rendNode;
                 if (val) {
-                    node.setAttributeNS(null, "display", "inline");
-                    node.style.visibility = "inherit";
+                    node.setAttributeNS(null, "display", 'inline');
+                    node.style.visibility = 'inherit';
                 } else {
-                    node.setAttributeNS(null, "display", "none");
-                    node.style.visibility = "hidden";
+                    node.setAttributeNS(null, "display", 'none');
+                    node.style.visibility = 'hidden';
                 }
             }
         },
@@ -1420,7 +1415,7 @@ JXG.extend(
                 node, node2, node3,
                 ev_g = el.evalVisProp('gradient');
 
-            if (ev_g === "linear" || ev_g === "radial") {
+            if (ev_g === "linear" || ev_g === 'radial') {
                 node = this.createPrim(ev_g + "Gradient", el.id + "_gradient");
                 node2 = this.createPrim("stop", el.id + "_gradient1");
                 node3 = this.createPrim("stop", el.id + "_gradient2");
@@ -1437,7 +1432,7 @@ JXG.extend(
                 el.gradNode2 = node3;
                 el.gradNode = node;
             } else {
-                fillNode.removeAttributeNS(null, "style");
+                fillNode.removeAttributeNS(null, 'style');
             }
         },
 
@@ -1505,22 +1500,22 @@ JXG.extend(
                     }, el.visPropOld.fillopacity);
                     //node.style['opacity'] = oo;  // This would overwrite values set by CSS class.
                 } else {
-                    if (c === "none") {
+                    if (c === 'none') {
                         // This is done only for non-images
                         // because images have no fill color.
                         oo = 0;
                         // This is necessary if there is a foreignObject below.
-                        node.setAttributeNS(null, "pointer-events", "visibleStroke");
+                        node.setAttributeNS(null, "pointer-events", 'visibleStroke');
                     } else {
                         // This is the default
-                        node.setAttributeNS(null, "pointer-events", "visiblePainted");
+                        node.setAttributeNS(null, "pointer-events", 'visiblePainted');
                     }
                     this._setAttribute(function () {
-                        node.setAttributeNS(null, "fill-opacity", oo);
+                        node.setAttributeNS(null, 'fill-opacity', oo);
                     }, el.visPropOld.fillopacity);
                 }
 
-                if (grad === "linear" || grad === "radial") {
+                if (grad === "linear" || grad === 'radial') {
                     this.updateGradient(el);
                 }
             }
@@ -1556,21 +1551,21 @@ JXG.extend(
                 node = el.rendNode;
 
                 if (el.elementClass === Const.OBJECT_CLASS_TEXT) {
-                    if (el.evalVisProp('display') === "html") {
+                    if (el.evalVisProp('display') === 'html') {
                         this._setAttribute(function () {
                             node.style.color = c;
                             node.style.opacity = oo;
                         }, el.visPropOld.strokecolor);
                     } else {
                         this._setAttribute(function () {
-                            node.setAttributeNS(null, "style", "fill:" + c);
-                            node.setAttributeNS(null, "style", "fill-opacity:" + oo);
+                            node.setAttributeNS(null, 'fill', c);
+                            node.setAttributeNS(null, 'fill-opacity', oo);
                         }, el.visPropOld.strokecolor);
                     }
                 } else {
                     this._setAttribute(function () {
                         node.setAttributeNS(null, "stroke", c);
-                        node.setAttributeNS(null, "stroke-opacity", oo);
+                        node.setAttributeNS(null, 'stroke-opacity', oo);
                     }, el.visPropOld.strokecolor);
                 }
 
@@ -1610,9 +1605,9 @@ JXG.extend(
             }
 
             node = el.rendNode;
-            this.setPropertyPrim(node, "stroked", "true");
+            this.setPropertyPrim(node, "stroked", 'true');
             if (Type.exists(w)) {
-                this.setPropertyPrim(node, "stroke-width", w + "px");
+                this.setPropertyPrim(node, "stroke-width", w + 'px');
 
                 // if (el.elementClass === Const.OBJECT_CLASS_CURVE ||
                 // el.elementClass === Const.OBJECT_CLASS_LINE) {
@@ -1652,7 +1647,7 @@ JXG.extend(
             //     el.evalVisProp('display') === "html"
             // ) {
             //     // transitionStr = " color " + duration + "ms," +
-            //     //     " opacity " + duration + "ms";
+            //     //     " opacity " + duration + 'ms'
             //     transitionStr = " all " + duration + "ms ease";
             // } else {
             //     transitionStr =
@@ -1664,7 +1659,7 @@ JXG.extend(
             //         " width " + duration + "ms," +
             //         " height " + duration + "ms," +
             //         " rx " + duration + "ms," +
-            //         " ry " + duration + "ms";
+            //         " ry " + duration + 'ms'
             // }
 
             if (Type.exists(props)) {
@@ -1761,7 +1756,7 @@ JXG.extend(
 
         // documented in JXG.AbstractRenderer
         setPropertyPrim: function (node, key, val) {
-            if (key === "stroked") {
+            if (key === 'stroked') {
                 return;
             }
             node.setAttributeNS(null, key, val);
@@ -1776,7 +1771,7 @@ JXG.extend(
             // if (el && el.rendNode) {
             //     node = el.rendNode;
             //     node.setAttributeNS(null, 'display', 'inline');
-            //     node.style.visibility = "inherit";
+            //     node.style.visibility = 'inherit'
             // }
         },
 
@@ -1815,9 +1810,9 @@ JXG.extend(
                 "offset",
                 el.evalVisProp('gradientendoffset') * 100 + "%"
             );
-            if (ev_g === "linear") {
+            if (ev_g === 'linear') {
                 this.updateGradientAngle(el.gradNode, el.evalVisProp('gradientangle'));
-            } else if (ev_g === "radial") {
+            } else if (ev_g === 'radial') {
                 this.updateGradientCircle(
                     el.gradNode,
                     el.evalVisProp('gradientcx'),
@@ -1922,11 +1917,11 @@ JXG.extend(
                 node.setAttributeNS(null, "d", "M 0 0");
                 this.touchpoints.push(node);
 
-                this.setPropertyPrim(node, "stroked", "true");
-                this.setPropertyPrim(node, "stroke-width", "1px");
+                this.setPropertyPrim(node, "stroked", 'true');
+                this.setPropertyPrim(node, "stroke-width", '1px');
                 node.setAttributeNS(null, "stroke", "#000000");
-                node.setAttributeNS(null, "stroke-opacity", 1.0);
-                node.setAttributeNS(null, "display", "none");
+                node.setAttributeNS(null, 'stroke-opacity', 1.0);
+                node.setAttributeNS(null, "display", 'none');
 
                 na2 = "touchpoint2_" + i;
                 node = this.createPrim("ellipse", na2);
@@ -1934,30 +1929,29 @@ JXG.extend(
                 this.updateEllipsePrim(node, 0, 0, 0, 0);
                 this.touchpoints.push(node);
 
-                this.setPropertyPrim(node, "stroked", "true");
-                this.setPropertyPrim(node, "stroke-width", "1px");
+                this.setPropertyPrim(node, "stroked", 'true');
+                this.setPropertyPrim(node, "stroke-width", '1px');
                 node.setAttributeNS(null, "stroke", "#000000");
-                node.setAttributeNS(null, "stroke-opacity", 1.0);
                 node.setAttributeNS(null, "fill", "#ffffff");
-                node.setAttributeNS(null, "fill-opacity", 0.0);
-
-                node.setAttributeNS(null, "display", "none");
+                node.setAttributeNS(null, 'stroke-opacity', 1.0);
+                node.setAttributeNS(null, 'fill-opacity', 0.0);
+                node.setAttributeNS(null, "display", 'none');
             }
         },
 
         // documented in JXG.AbstractRenderer
         showTouchpoint: function (i) {
             if (this.touchpoints && i >= 0 && 2 * i < this.touchpoints.length) {
-                this.touchpoints[2 * i].setAttributeNS(null, "display", "inline");
-                this.touchpoints[2 * i + 1].setAttributeNS(null, "display", "inline");
+                this.touchpoints[2 * i].setAttributeNS(null, "display", 'inline');
+                this.touchpoints[2 * i + 1].setAttributeNS(null, "display", 'inline');
             }
         },
 
         // documented in JXG.AbstractRenderer
         hideTouchpoint: function (i) {
             if (this.touchpoints && i >= 0 && 2 * i < this.touchpoints.length) {
-                this.touchpoints[2 * i].setAttributeNS(null, "display", "none");
-                this.touchpoints[2 * i + 1].setAttributeNS(null, "display", "none");
+                this.touchpoints[2 * i].setAttributeNS(null, "display", 'none');
+                this.touchpoints[2 * i + 1].setAttributeNS(null, "display", 'none');
             }
         },
 
@@ -2026,10 +2020,10 @@ JXG.extend(
         // _getDataUri: function (url, callback) {
         //     var image = new Image();
         //     image.onload = function () {
-        //         var canvas = document.createElement("canvas");
+        //         var canvas = document.createElement('canvas');
         //         canvas.width = this.naturalWidth; // or 'width' if you want a special/scaled size
         //         canvas.height = this.naturalHeight; // or 'height' if you want a special/scaled size
-        //         canvas.getContext("2d").drawImage(this, 0, 0);
+        //         canvas.getContext('2d').drawImage(this, 0, 0);
         //         callback(canvas.toDataURL("image/png"));
         //         canvas.remove();
         //     };
@@ -2039,19 +2033,19 @@ JXG.extend(
         _getImgDataURL: function (svgRoot) {
             var images, len, canvas, ctx, ur, i;
 
-            images = svgRoot.getElementsByTagName("image");
+            images = svgRoot.getElementsByTagName('image');
             len = images.length;
             if (len > 0) {
-                canvas = document.createElement("canvas");
+                canvas = document.createElement('canvas');
                 //img = new Image();
                 for (i = 0; i < len; i++) {
-                    images[i].setAttribute("crossorigin", "anonymous");
+                    images[i].setAttribute("crossorigin", 'anonymous');
                     //img.src = images[i].href;
                     //img.onload = function() {
-                    // img.crossOrigin = "anonymous";
-                    ctx = canvas.getContext("2d");
-                    canvas.width = images[i].getAttribute("width");
-                    canvas.height = images[i].getAttribute("height");
+                    // img.crossOrigin = 'anonymous'
+                    ctx = canvas.getContext('2d');
+                    canvas.width = images[i].getAttribute('width');
+                    canvas.height = images[i].getAttribute('height');
                     try {
                         ctx.drawImage(images[i], 0, 0, canvas.width, canvas.height);
 
@@ -2125,7 +2119,7 @@ JXG.extend(
             // of an input element. Therefore, we do it "by hand".
             if (this.container.hasChildNodes() && Type.exists(this.foreignObjLayer)) {
                 if (!ignoreTexts) {
-                    this.foreignObjLayer.setAttribute("display", "inline");
+                    this.foreignObjLayer.setAttribute("display", 'inline');
                 }
                 while (svgRoot.nextSibling) {
                     // Copy all value attributes
@@ -2180,7 +2174,7 @@ JXG.extend(
                 while (this.foreignObjLayer.firstChild) {
                     this.container.appendChild(this.foreignObjLayer.firstChild);
                 }
-                this.foreignObjLayer.setAttribute("display", "none");
+                this.foreignObjLayer.setAttribute("display", 'none');
             }
 
             return "data:image/svg+xml;base64," + btoa(unescape(encodeURIComponent(svg)));
@@ -2226,10 +2220,10 @@ JXG.extend(
             cv.width = cv.width;
             /* eslint-enable no-self-assign */
 
-            ctx = cv.getContext("2d");
+            ctx = cv.getContext('2d');
             if (w !== undefined && h !== undefined) {
-                cv.style.width = parseFloat(w) + "px";
-                cv.style.height = parseFloat(h) + "px";
+                cv.style.width = parseFloat(w) + 'px';
+                cv.style.height = parseFloat(h) + 'px';
                 // Scale twice the CSS size to make the image crisp
                 // cv.setAttribute('width', 2 * parseFloat(wOrg));
                 // cv.setAttribute('height', 2 * parseFloat(hOrg));
@@ -2316,7 +2310,7 @@ JXG.extend(
                 _copyCanvasToImg,
                 isDebug = false;
 
-            if (this.type === "no") {
+            if (this.type === 'no') {
                 return this;
             }
 
@@ -2326,8 +2320,8 @@ JXG.extend(
             if (imgId === undefined || imgId === "") {
                 newImg = true;
                 img = new Image(); //doc.createElement('img');
-                img.style.width = w + "px";
-                img.style.height = h + "px";
+                img.style.width = w + 'px';
+                img.style.height = h + 'px';
             } else {
                 newImg = false;
                 img = doc.getElementById(imgId);
@@ -2336,29 +2330,29 @@ JXG.extend(
 
             // Create div which contains canvas element and close button
             if (newImg) {
-                node = doc.createElement("div");
+                node = doc.createElement('div');
                 node.style.cssText = bas.css;
-                node.style.width = w + "px";
-                node.style.height = h + "px";
+                node.style.width = w + 'px';
+                node.style.height = h + 'px';
                 node.style.zIndex = this.container.style.zIndex + 120;
 
                 // Try to position the div exactly over the JSXGraph board
-                node.style.position = "absolute";
-                node.style.top = this.container.offsetTop + "px";
-                node.style.left = this.container.offsetLeft + "px";
+                node.style.position = 'absolute';
+                node.style.top = this.container.offsetTop + 'px';
+                node.style.left = this.container.offsetLeft + 'px';
             }
 
             if (!isDebug) {
                 // Create canvas element and add it to the DOM
                 // It will be removed after the image has been stored.
-                canvas = doc.createElement("canvas");
+                canvas = doc.createElement('canvas');
                 id = Math.random().toString(36).slice(2, 7);
                 canvas.setAttribute("id", id);
                 canvas.setAttribute("width", w);
                 canvas.setAttribute("height", h);
-                canvas.style.width = w + "px";
-                canvas.style.height = w + "px";
-                canvas.style.display = "none";
+                canvas.style.width = w + 'px';
+                canvas.style.height = w + 'px';
+                canvas.style.display = 'none';
                 parent.appendChild(canvas);
             } else {
                 // Debug: use canvas element 'jxgbox_canvas' from jsxdev/dump.html
@@ -2368,7 +2362,7 @@ JXG.extend(
 
             if (newImg) {
                 // Create close button
-                button = doc.createElement("span");
+                button = doc.createElement('span');
                 buttonText = doc.createTextNode("\u2716");
                 button.style.cssText = bas.cssButton;
                 button.appendChild(buttonText);
@@ -2386,7 +2380,7 @@ JXG.extend(
             navbar = doc.getElementById(this.uniqName('navigationbar'));
             if (Type.exists(navbar)) {
                 navbarDisplay = navbar.style.display;
-                navbar.style.display = "none";
+                navbar.style.display = 'none';
                 insert = this.removeToInsertLater(navbar);
             }
 
