@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2024
+    Copyright 2008-2025
         Matthias Ehmann,
         Carsten Miller,
         Andreas Walter,
@@ -33,9 +33,10 @@ describe("Test geometry functions", function () {
         '<div id="jxgbox" style="width: 100px; height: 100px;"></div>';
     board = JXG.JSXGraph.initBoard("jxgbox", {
         renderer: "svg",
-        axis: false,
+        axis: true,
         grid: false,
-        boundingbox: [-8, 8, 8, -8],
+        // boundingbox: [-8, 8, 8, -8],
+        boundingbox: [-10, 10, 10, -10],
         resize: {enabled: false},
         showCopyright: false,
         showNavigation: false
@@ -57,6 +58,48 @@ describe("Test geometry functions", function () {
         expect(JXG.Math.Geometry.affineRatio(a, b, c)).toEqual(3);
     });
 
+    it("intersectingFunctiongraphs", function () {
+        var f1 = board.create("functiongraph", ["(x-1)**2", -10, 10]); // The exponent 2 fails
+        var f2 = board.create("functiongraph", ["0", -10, 10]);
+        var inter = board.create("intersection", [f1, f2]);
+        // var c = JXG.Math.Geometry.meetCurveCurve(f1, f2, 0, 0, board).usrCoords;
+        // console.log('intersection', inter.X())
+        expect(inter.X()).toBeCloseTo(1, 2);
+    });
+
+    it("intersectingCurveCurve", function () {
+      const f1 = board.create("functiongraph", ["sin(x)", -10, 10], { fixed: false });
+      const f2 = board.create("functiongraph", ["0", -10, 10], {});
+
+      const inter = board.create("intersection", [f1, f2, 5]);
+      expect(inter.X()).toBeCloseTo(Math.PI * 2, 4);
+    });
+
+    it("intersectingCurveCurve 2", function () {
+        const f1 = board.create("functiongraph", ["sin(x)"], { fixed: false }); // ["sin(x)", -10, 10] fails
+        const f2 = board.create("functiongraph", ["0"], {});
+
+        const inter = board.create("intersection", [f1, f2, 6]);
+        expect(inter.X()).toBeCloseTo(Math.PI * 3, 4); // 9.42477796076938
+    });
+
+    it("intersectingCurveLine", function () {
+        const f1 = board.create("functiongraph", ["(x + 1)**2 * (x - 1)**2", -10, 10], {});
+        // const f2 = board.create("functiongraph", ["0", -10, 10], {});
+        const f2 = board.defaultAxes.x;
+
+        const inter1 = board.create("point", [
+            () => JXG.Math.Geometry.meetCurveCurve(f1, f2, -1.5, 0, f1.board, 'newton')
+        ], { name: 'A' });
+
+        const inter2 = board.create("point", [
+            () => JXG.Math.Geometry.meetCurveCurve(f1, f2, 1.5, 1, f1.board, 'newton')
+        ], { name: 'B' });
+
+        expect(inter1.X()).toBeCloseTo(-1.0116589163799947, 4);
+        expect(inter2.X()).toBeCloseTo(1.0116589163799947, 4);
+    });
+
     it("meetSegmentSegment", function () {
         var res = JXG.Math.Geometry.meetSegmentSegment(
             [1, -1, -1],
